% "Using geographically weighted choice models 
% to account for spatial heterogeneity of preferences" (2016)
% Budzinski, Czajkowski, Campbell, Hanley
% 2016-03-14 version

% Calculation of Geographically Weighted MNL (GWMNL)

% This code uses Tools package from https://github.com/czaj/Tools
% Functions from GWMNL folder needs to be added to path as well

if exist('output','dir') == 0
	mkdir('output') 
end

% diary('output\diary')

clear all
clc

global B_backup; % this one is for storing B in case iterations are interrupted with ctrl-c
global Band_backup; % for GWR only
rng(10000001);
%% ****************************  loading & specifying data ****************************

EstimOpt.fnameinput = ('polforex_2.9.mat'); 
DATA = load(EstimOpt.fnameinput);
DATA.Y = DATA.ATT.ANS == 1;
DATA.X = [DATA.ATT.ALT == 1, DATA.ATT.N == 1, DATA.ATT.N == 2, DATA.ATT.S == 1, DATA.ATT.S == 2, DATA.ATT.I == 1, DATA.ATT.I == 2, -DATA.ATT.K/4];

%% ****************************  loading & specifying input ****************************

INPUT.Y = DATA.Y+0;
INPUT.Xa = DATA.X;
INPUT.MissingInd = zeros(size(INPUT.Y,1),1);

%% ****************************  sample characteristics ****************************

EstimOpt.NP = 1001; % Number of respondents
EstimOpt.NCT = 26; % Number of choice tasks per person 
EstimOpt.NAlt = 4; % Number of alternatives


[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);

%% ************************** Models *******************************


%EstimOpt.NumGrad = 0;
Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt); % estimating MNL first
%Results.MNL.bhat = [37.2442815803449;14.8307066185804;21.8206916502481;26.6696629539553;35.6781853312007;12.1399902278437;19.5598077038486;0.0537803792036215];

% Defining coordinates for weighting
%INPUT.Crds = [DATA.GIS1.Longitude(1:4*26:end), DATA.GIS1.Latitude(1:4*26:end)];
INPUT.Crds = DATA.Crds2; % these are projected latitudes and longitudes, they were rescaled to have the same mean and std. as latitude and longitude


EstimOpt.Clustered = 1; % with clustered standard errors
EstimOpt.BandSearch = 0; % without searching for optimal bandwidth
EstimOpt.BandType = 1; % with gaussian bandwidth
EstimOpt.WeightSum = 3;

% Model for Appendix A in preference space
EstimOpt.BandVal = 0.275; % with defined value of bandwidth
EstimOpt.HessEstFix = 1;
Results.GWMNL00 = GWMNL(INPUT,Results,EstimOpt,OptimOpt);
EstimOpt.StartMatFull = 1;
B_backup = Results.GWMNL00.bhat;
B_backup(1:7,:) = B_backup(1:7,:)./B_backup(8*ones(1,7),:);
EstimOpt.WTP_space = 1; % estimation in WTP-space
EstimOpt.HessEstFix = 0;
% WTP-space equivalent
Results.GWMNL0 = GWMNL(INPUT,Results,EstimOpt,OptimOpt);

% Main model in the paper
EstimOpt.WTP_space = 0;
EstimOpt.StartMatFull = 0;
EstimOpt.BandVal = 0.475; % with defined value of bandwidth
% in preference space
B_backup = Results.MNL.bhat;
EstimOpt.HessEstFix = 1;
Results.GWMNL10 = GWMNL(INPUT,Results,EstimOpt,OptimOpt);
EstimOpt.StartMatFull = 1;
B_backup = Results.GWMNL10.bhat;
B_backup(1:7,:) = B_backup(1:7,:)./B_backup(8*ones(1,7),:);
EstimOpt.WTP_space = 1; % estimation in WTP-space
% WTP-space equivalent
EstimOpt.HessEstFix = 0;
Results.GWMNL1 = GWMNL(INPUT,Results,EstimOpt,OptimOpt);

% Second model for Appendix A in preference space
EstimOpt.WTP_space = 0;
EstimOpt.StartMatFull = 0;
EstimOpt.BandVal = 0.6; % with defined value of bandwidth
% in preference space
B_backup = Results.MNL.bhat;
EstimOpt.HessEstFix = 1;
Results.GWMNL20 = GWMNL(INPUT,Results,EstimOpt,OptimOpt);
EstimOpt.StartMatFull = 1;
B_backup = Results.GWMNL20.bhat;
B_backup(1:7,:) = B_backup(1:7,:)./B_backup(8*ones(1,7),:);
EstimOpt.WTP_space = 1; % estimation in WTP-space
EstimOpt.HessEstFix = 0;
% WTP-space equivalent
Results.GWMNL2 = GWMNL(INPUT,Results,EstimOpt,OptimOpt);

