% "Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
% Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

% Online codes
% 2017-10-18 version

% This codes calculates MNL and MXL models for Table 2

% This code uses Tools package from https://github.com/czaj/Tools
% This code uses DCE package from https://github.com/czaj/DCE


%%


clear all
clc

global B_backup; % this is for storing B in case iterations are interrupted with ctrl-c


%% ****************************  loading & specifying data ****************************

EstimOpt.fnameinput = ('polforex_2.8.mat'); 
DATA = load(EstimOpt.fnameinput);

%% ****************************  loading & specifying input ****************************

DATA.Y = DATA.ATT.ANS == 1;
DATA.X = [DATA.ATT.ALT == 1, DATA.ATT.N == 1, DATA.ATT.N == 2, DATA.ATT.S == 1, DATA.ATT.S == 2, DATA.ATT.I == 1, DATA.ATT.I == 2, -DATA.ATT.K/4];
DATA.Crds = [DATA.GIS1.Longitude(1:4*26:end), DATA.GIS1.Latitude(1:4*26:end)];

%% ****************************  sample characteristics ****************************
EstimOpt.NCT =26; % Number of choice tasks per person 
EstimOpt.NAlt = 4; % Number of alternatives
EstimOpt.NP = length(DATA.Y)/EstimOpt.NCT/EstimOpt.NAlt; % 789; % Number of respondents
EstimOpt.NVarA = 8;

[Y,X, EstimOpt] = TransformDataSet(DATA.Y, DATA.X, DATA.Crds, EstimOpt);
EstimOpt.MissingInd = zeros(length(Y),1);
EstimOpt.MissingInd(isnan(Y)) = 1;
INPUT.MissingInd = EstimOpt.MissingInd;
INPUT.Y = Y;
INPUT.Xa = X;
EstimOpt.NamesA = {'SQ';'NAT1'; 'NAT2'; 'TRA1'; 'TRA2'; 'INF1'; 'INF2'; 'FEE' }; 


%% **************************** estimation and optimization options ****************************

[INPUT, Results, EstimOpt, OptimOpt] = DataCleanDCE(INPUT,EstimOpt);
 EstimOpt.NRep = 10000; % number of draws for numerical simulation
% EstimOpt.eps = 1.e-9; % overall precision level
% OptimOpt.MaxIter = 1e3; % maximum number of iterations

% OptimOpt.Algorithm = 'quasi-newton'; % 'trust-region'
%EstimOpt.NumGrad = 0; % 1
% OptimOpt.GradObj = 'on'; % 'off'
% OptimOpt.FinDiffType = 'central'; % 'forward'
% OptimOpt.Hessian = 'user-supplied'; % 'off'
EstimOpt.HessEstFix = 1; % 0 = use optimization Hessian, 1 = use jacobian-based (BHHH) Hessian, 2 - use high-precision jacobian-based (BHHH) Hessian 3 - use numerical Hessian

%% ****************************     MNL     ****************************


Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);
EstimOpt.WTP_space = 1;

B_backup = [Results.MNL.bhat(1:7)/Results.MNL.bhat(8); Results.MNL.bhat(8)];
Results.MNL = MNL(INPUT,Results,EstimOpt,OptimOpt);
%% ****************************     MXL     ****************************

EstimOpt.FullCov = 1;
EstimOpt.Dist = [zeros(1,7),1];
EstimOpt.Scores = 1;

% Reported in the paper 
B_backup = [-2.06501852543685;11.9259563516897;17.4327362871538;18.1247311219328;26.4371844461495;8.58701232032900;13.0063062309706;-2.19770818313425;39.4760018053022;-2.67308367816607;-4.82774443609745;-1.95310326836504;-4.92731161003520;-0.422155851444729;-0.597435797429732;-0.102158853196026;7.56546624941862;11.5465900326190;3.46933859828124;6.31751527918260;-0.306798134445137;0.384888857701757;-0.423101191648260;1.40851812988062;7.00355116764357;11.6594707731968;1.68626738298766;3.08784061156386;-0.243348916872418;5.55729056554277;6.09510475438056;4.75088640974443;6.27035808493997;-0.555435689686228;-2.12480859819163;0.507119842690427;-0.503617244178840;0.0386007442420450;-0.489230394785887;-0.0366647022350692;-0.171498698555352;-0.852857329601973;-0.341400353002627;-0.0797012966720000];
Results.MXL = MXL(INPUT,Results,EstimOpt,OptimOpt);