#"Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
# Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

# Online codes
# 2017-10-22 version

#Figure 3. Spatial distribution of differences between WTP estimates from GWMNL and conditional expected values from location-specific MXL.

# Input
# File dane10kmnowe.shp, used for drawinf a map
# File Crds0910.csv, with individuals' coordinates for the map
# File LocalMxlScores.mat, which can be calculated using MXLcalc.m and Figure3a.m codes
# File GWMNL_beta.mat, which can be calculated using GWRcalc.m codes. (Results.GWMNL1.bhat matrix)

# Reading libraries
library(spdep)
library(maptools)
library(sp)
library(RColorBrewer)
library(classInt)
library(kriging)
library(mgcv)
library(GISTools)
library(R.matlab)

# Reading datasets (set your own paths)

# For maps
setwd("C:\\Users\\wbudzinski\\Documents\\praca\\GWR\\20170929\\For maps")

# Reading shapefile
pl<-readShapePoly("dane10kmnowe.shp")
crds2<-coordinates(pl)

# Reading jittered coordinates 
crds<-read.csv("Crds0910.csv", sep=",",dec = ".",  header=TRUE) 

# Reading location specific MXL results
Local<-readMat("LocalMxlScores.mat")
WTP_MXL <- Local$Scores

#  GWMNL results
GWMNL<-readMat("GWMNL_beta.mat")
WTP_GWMNL<-GWMNL$Beta

### Drawing###
# choose which map you want to draw (SQ, NAT1, NAT2, TRA1, TRA2, INF1, INF2)
X<-WTP_GWMNL[,1]-WTP_MXL[,1]
#X<-WTP_GWMNL[,2]-WTP_MXL[,2]
#X<-WTP_GWMNL[,3]-WTP_MXL[,3]
#X<-WTP_GWMNL[,4]-WTP_MXL[,4]
#X<-WTP_GWMNL[,5]-WTP_MXL[,5]
#X<-WTP_GWMNL[,6]-WTP_MXL[,6]
#X<-WTP_GWMNL[,7]-WTP_MXL[,7]

kolory<-brewer.pal(9, "YlOrRd")  # wybr kolorw
klasy<-classIntervals(X, style="quantile", n = 9)
tabela.kolorow<-findColours(klasy, kolory) 

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
# leg10<-paste("[" , as.character(round(klasy$brks[10],2)) , ",",  as.character(round(klasy$brks[11],2)),")", sep="")
# leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9, leg10)
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)

plot(pl)
points(crds, pch=21, bg=tabela.kolorow, cex=1.8) 

# choose one with appropriate description
legend(x =-240000 ,y=690000, legend=leg,title = expression(WTP~'differences for'~italic(SQ)), fill=attr(tabela.kolorow, "palette"), 
      cex=0.85, bty="n", y.intersp = 0.6)
#legend(x =-240000 ,y=690000, legend=leg,title = expression(WTP~'differences for'~italic(NAT)[1]), fill=attr(tabela.kolorow, "palette"), 
#       cex=0.85, bty="n", y.intersp = 0.6)
#legend(x =-240000 ,y=690000, legend=leg,title = expression(WTP~'differences for'~italic(NAT)[2]), fill=attr(tabela.kolorow, "palette"), 
#       cex=0.85, bty="n", y.intersp = 0.6)
#legend(x =-240000 ,y=690000, legend=leg,title = expression(WTP~'differences for'~italic(TRA)[1]), fill=attr(tabela.kolorow, "palette"), 
#       cex=0.85, bty="n", y.intersp = 0.6)
#legend(x =-240000 ,y=690000, legend=leg,title = expression(WTP~'differences for'~italic(TRA)[2]), fill=attr(tabela.kolorow, "palette"), 
#       cex=0.85, bty="n", y.intersp = 0.6)
#legend(x =-240000 ,y=690000, legend=leg,title = expression(WTP~'differences for'~italic(INF)[1]), fill=attr(tabela.kolorow, "palette"), 
#      cex=0.85, bty="n", y.intersp = 0.6)
#legend(x =-240000 ,y=690000, legend=leg,title = expression(WTP~'differences for'~italic(INF)[2]), fill=attr(tabela.kolorow, "palette"), 
#       cex=0.85, bty="n", y.intersp = 0.6)

map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)
x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)


#xy = locator(1) # click on whatever
xy<-{}
xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)
