% "Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
% Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

% Online codes
% 2017-10-18 version

% Figure A1. Parameters values with different bandwidths values plotted against longitude

% Input
% File GWMNL_results.mat, which can be calculated using GWMNLcalc.m code
% File polforex_2.8.mat, which contains Latitude and Longitude coordinates

%%
tic
clear
clc
load('GWMNL_results.mat');
% Bandwidth = 0.45
B1 = Results.GWMNL1.bhat';
STD1 = Results.GWMNL1.std';
UP1 = B1 + 1.96*STD1;
LOW1 = B1 - 1.96*STD1;

% Bandwidth = 0.275
B2 = Results.GWMNL0.bhat';
STD2 = Results.GWMNL0.std';
UP2 = B2 + 1.96*STD2;
LOW2 = B2 - 1.96*STD2;

% Bandwidth = 0.6
B3 = Results.GWMNL2.bhat';
STD3 = Results.GWMNL2.std';
UP3 = B3 + 1.96*STD3;
LOW3 = B3 - 1.96*STD3;


EstimOpt.fnameinput = ('polforex_2.8.mat'); 
DATA = load(EstimOpt.fnameinput);
Crds = [DATA.GIS1.Longitude(1:4*26:end), DATA.GIS1.Latitude(1:4*26:end)];

% Columns are: Longitude, latitude, and then 9 columns (3 for estimates
% with different bandwidths and 6 for their confidence intervals) for every
% parameter

X = zeros(1001,2+ 8*3*3);
X(:,1:2) = Crds;
X(:,3:9:end) = B1;
X(:,4:9:end) = LOW1;
X(:,5:9:end) = UP1;
X(:,6:9:end) = B2;
X(:,7:9:end) = LOW2;
X(:,8:9:end) = UP2;
X(:,9:9:end) = B3;
X(:,10:9:end) = LOW3;
X(:,11:9:end) = UP3;

[CrdsX, ia] = unique(Crds, 'rows'); 

X = X(ia,:);
toc

% Matrix X can be exported to excel and then plotted