% "Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
% Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

% Online codes
% 2017-10-18 version

% Table 2. Results of the MNL, location specific MXL and GWMNL models (standard errors in brackets, coefficients in WTP-space, in EUR per year)

% This code uses Tools package from https://github.com/czaj/Tools

% Input
% File GWMNL_results.mat, which can be calculated using GWMNLcalc.m code
% File MXL_results_new.mat, which can be calculated using MXLcalc.m code
% File MNL_results.mat, which can be calculated using MXLcalc.m code

%% for GWR 

clear
clc
tic;
load('GWMNL_results.mat');
B = Results.GWMNL1.bhat; % bandwidth = 0.45
rng(10000001); % setting seed
n = 10000;% no. of repetitions in the simulation
ihess = Results.GWMNL1.ihess;
Beta = zeros(n,8,1001);

for i = 1:1001
   BX = normrnd(0,1,8,n);
   V = chol(ihess(:,:,i),'lower');
   BX = B(:,i*ones(n,1))+V*BX;
   Beta(:,:,i) = BX';

end

M1 = mean(Beta,3);
M2 = median(Beta,3);
S1 = std(Beta,[],3);
P025 = prctile(Beta, 2.5, 3);
P975 = prctile(Beta, 97.5, 3);


T_gwr = zeros(2*8, 2);
T_gwr(1:2:end,:) = [mean(M1,1)',mean(S1,1)'];
T_gwr(2:2:end,:) = [std(M1,[],1)',std(S1,[],1)'];
T_gwr = T_gwr([3:14, 1:2, 15:16],:);
P_gwr = zeros(8,2);
P_gwr(:,1) = pv(T_gwr(1:2:end,1), T_gwr(2:2:end,1));
P_gwr(:,2) = pv(T_gwr(1:2:end,2), T_gwr(2:2:end,2));

%% For MXL

load('MXL_results_new.mat');
Results.MXL = Results.MXL2;
T_mxl = zeros(2*8, 2);
T_mxl(1:2:end,:) = [Results.MXL.DetailsA(:,1), Results.MXL.DetailsV(:,1)];
T_mxl(2:2:end,:) = [Results.MXL.DetailsA(:,3), Results.MXL.DetailsV(:,3)];
T_mxl = T_mxl([3:14, 1:2, 15:16],:);
P_mxl = zeros(8,2);
P_mxl(:,1)  = pv(T_mxl(1:2:end,1), T_mxl(2:2:end,1));
P_mxl(:,2)  = pv(T_mxl(1:2:end,2), T_mxl(2:2:end,2));

%% For MNL

load('MNL_results.mat');
T_mnl = zeros(2*8, 1);
T_mnl(1:2:end,:) = [Results.MNL.DetailsA(:,1)];
T_mnl(2:2:end,:) = [Results.MNL.DetailsA(:,3)];
T_mnl = T_mnl([3:14, 1:2, 15:16],:);
P_mnl = pv(T_mnl(1:2:end,:), T_mnl(2:2:end,:));

%% Out 
TabOut = cell(17, 6);
TabOut(1,2:6) = {'MNL', 'MXL - mean', 'MXL - std', 'GWR - mean', 'GWR - std'};
T = [T_mnl, T_mxl, T_gwr];
T = reshape(T, [2,8,5]);
P = [P_mnl, P_mxl, P_gwr];

for i = 1:8
    for j = 1:5
         Tmp = P(i,j);
         Tmp2 = T(:,i,j);
         if Tmp< 0.01
             TabOut(1+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), '***']}; 
        elseif Tmp <= 0.05 && Tmp > 0.01
            TabOut(1+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), '**']}; 
        elseif Tmp <= 0.1 && Tmp > 0.05
            TabOut(1+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), '*']}; 
        elseif Tmp > 0.1
            TabOut(1+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), ' ']};  
         end
        TabOut(1+2*i,1+j) = {['''(', num2str(Tmp2(2), '%8.2f'), ')']}; 
    end
end

TabOut(2:2:16,1) ={'NAT1'; 'NAT2'; 'TRA1'; 'TRA2'; 'INF1'; 'INF2';'SQ'; 'COST' }; 
% TabOut can be then exported to excel
xlswrite('GWR_Tab2.xls', TabOut,'Table2', 'B2');
toc;