#"Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
# Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

# Online codes
# 2017-10-22 version

# Table 5. Results of spatial lag models in which Bayesian posterior means from MXL model are explained by GIS variables

# Input
# File SpatialLagInput.csv, which contains data on coordinates, GIS explanatory variables and location-specific
# WTP from MXL (calculated with MXLcalc.m codes)

# Reading packages

library(spdep)
library(maptools)
library(sp)
library(RColorBrewer)
library(classInt)
library(R.matlab)
########################## Location specific MXL ###################################

# File with data from location-specific MXL in .csv format for convenience
setwd("C:\\Users\\wbudzinski\\Documents\\praca\\GWR\\20170929")
dane<-read.csv("SpatialLagInput.csv", sep=";",dec = ".",  header=TRUE) 

# Calculating spatial weights matrix
crdsmat <-data.matrix(dane[,c(8,9)]) #converting into matrix class
kw10km<-knearneigh(crdsmat, k=252) 
kw10kmnb<-knn2nb(kw10km) 
dist<-nbdists(kw10kmnb, crdsmat)
dist2<-lapply(dist, function(x) 1/(x^2))  
kw10kmdist2<-nb2listw(kw10kmnb, glist=dist2) 

# Scaling variables

dane$Wiek4<-dane$Wiek4/100
dane$Lgat3<-dane$Lgat3/100
dane$Igla<-dane$Igla/100
dane$Lisc<-dane$Lisc/100
dane$Miesz<-dane$Miesz/100
dane$EuclAvg<-dane$EuclAvg/1000
dane$Zabud<-dane$Zabud/100

############################# Estimation ################################

A<- matrix(nrow = 17, ncol=7,0)
# SQ
rownanie1 <- SQ ~  Igla + Lisc+ Miesz+ Wiek4 +EuclAvg 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
summary(GIS2error)

A[seq(from = 1, to = 11, by = 2),1]<- GIS2error$coefficients
A[seq(from = 2, to = 12, by = 2),1]<- GIS2error$rest.se
A[13,1]<- GIS2error$rho
A[14,1]<- GIS2error$rho.se
A[16,1]<-GIS2error$AIC_lm.model/253
A[15,1]<-GIS2error$LL
A[17,1]<-GIS2error$parameters 

# NAT models 
rownanie1 <- NAT1 ~  Igla + Lisc+ Miesz+ Wiek4 +EuclAvg
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
#summary(GIS2error)

A[seq(from = 1, to = 11, by = 2),2]<- GIS2error$coefficients
A[seq(from = 2, to = 12, by = 2),2]<- GIS2error$rest.se
A[13,2]<- GIS2error$rho
A[14,2]<- GIS2error$rho.se
A[16,2]<-GIS2error$AIC_lm.model/253
A[15,2]<-GIS2error$LL
A[17,2]<-GIS2error$parameters 

rownanie1 <- NAT2 ~  Igla + Lisc+ Miesz+ Wiek4 +EuclAvg 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
#summary(GIS2error)

A[seq(from = 1, to = 11, by = 2),3]<- GIS2error$coefficients
A[seq(from = 2, to = 12, by = 2),3]<- GIS2error$rest.se
A[13,3]<- GIS2error$rho
A[14,3]<- GIS2error$rho.se
A[16,3]<-GIS2error$AIC_lm.model/253
A[15,3]<-GIS2error$LL
A[17,3]<-GIS2error$parameters 

# TRA models

rownanie1 <- TRA1 ~  Igla + Lisc+ Miesz+ Wiek4 +EuclAvg 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
#summary(GIS2error)
A[seq(from = 1, to = 11, by = 2),4]<- GIS2error$coefficients
A[seq(from = 2, to = 12, by = 2),4]<- GIS2error$rest.se
A[13,4]<- GIS2error$rho
A[14,4]<- GIS2error$rho.se
A[16,4]<-GIS2error$AIC_lm.model/253
A[15,4]<-GIS2error$LL
A[17,4]<-GIS2error$parameters 

rownanie1 <- TRA2 ~  Igla + Lisc+ Miesz+ Wiek4 +EuclAvg 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
#summary(GIS2error)

A[seq(from = 1, to = 11, by = 2),5]<- GIS2error$coefficients
A[seq(from = 2, to = 12, by = 2),5]<- GIS2error$rest.se
A[13,5]<- GIS2error$rho
A[14,5]<- GIS2error$rho.se
A[16,5]<-GIS2error$AIC_lm.model/253
A[15,5]<-GIS2error$LL
A[17,5]<-GIS2error$parameters 

# INF models
rownanie1 <- INF1 ~  Igla + Lisc+ Miesz+ Wiek4 +EuclAvg 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
# summary(GIS2error)
A[seq(from = 1, to = 11, by = 2),6]<- GIS2error$coefficients
A[seq(from = 2, to = 12, by = 2),6]<- GIS2error$rest.se
A[13,6]<- GIS2error$rho
A[14,6]<- GIS2error$rho.se
A[16,6]<-GIS2error$AIC_lm.model/253
A[15,6]<-GIS2error$LL
A[17,6]<-GIS2error$parameters 


rownanie1 <- INF2 ~  Igla + Lisc+ Miesz+ Wiek4 +EuclAvg 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
#summary(GIS2error)

A[seq(from = 1, to = 11, by = 2),7]<- GIS2error$coefficients
A[seq(from = 2, to = 12, by = 2),7]<- GIS2error$rest.se
A[13,7]<- GIS2error$rho
A[14,7]<- GIS2error$rho.se
A[16,7]<-GIS2error$AIC_lm.model/253
A[15,7]<-GIS2error$LL
A[17,7]<-GIS2error$parameters
# Writing results to matlab
writeMat("SpatiaLagRes.mat", A = A) 