% "Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
% Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

% Online codes
% 2017-10-18 version

% Table 5.  Results of spatial lag models in which Bayesian posterior means from MXL model are explained by GIS variables. 

% This code uses output from Table5 codes in R
% This code uses Tools package from https://github.com/czaj/Tools

% Input
% File SpatiaLagRes.mat, which can be calculated using Table5.R codes
%% 
clear
clc

load('SpatiaLagRes.mat')

TabOut = cell(18,8);
TabOut(1,2:8) ={'SQ'; 'NAT1'; 'NAT2'; 'TRA1'; 'TRA2'; 'INF1'; 'INF2' }; 
T = reshape(A(1:14,:), [2, 7, 7]);
for i = 1:7 % SQ, NAT1... INF2
    for j = 1:7 % Different variables 
         Tmp = T(:,j,i);
         P = pv(Tmp(1), Tmp(2));
         if P< 0.01
             TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), '***']}; 
        elseif P <= 0.05 && P > 0.01
            TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), '**']}; 
        elseif P <= 0.1 && P > 0.05
            TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), '*']}; 
        elseif P > 0.1
            TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), ' ']};  
         end
        TabOut(1+2*j,1+i) = {['''(', num2str(Tmp(2), '%8.2f'), ')']}; 
    end 
    TabOut(16,1+i)  = {[num2str(A(15,i), '%8.2f')]}; 
    TabOut(17,1+i)  = {[num2str(A(16,i), '%8.2f')]}; 
    TabOut(18,1+i)  = {[num2str(A(17,i), '%8.2f')]}; 
end
TabOut(2:2:14,1) ={'Cons'; 'Coniferous'; 'Decidous'; 'Mixed'; 'Age > 120'; 'Euclidean distance'; 'Rho' }; 
TabOut(16:18,1) ={'LL'; 'AIC/n'; 'k'};
xlswrite('GWR_Tab5.xls', TabOut,'Table5', 'B2');

