% "Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
% Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

% Online codes
% 2017-10-22 version

% Table A1. Characteristics of distributions of estimated WTP from GWMNL model for different bandwidth values 

% This code uses Tools package from https://github.com/czaj/Tools

% Input
% File GWMNL_results.mat, which can be calculated using GWMNLcalc.m code

clear
clc
tic;
load('GWMNL_results.mat');
%% bandwidth = 0.45
B = Results.GWMNL1.bhat; 
rng(10000001); % setting seed
n = 10000;% no. of repetitions in the simulation
ihess = Results.GWMNL1.ihess;
Beta = zeros(n,8,1001);

for i = 1:1001
   BX = normrnd(0,1,8,n);
   V = chol(ihess(:,:,i),'lower');
   BX = B(:,i*ones(n,1))+V*BX;
   Beta(:,:,i) = BX';
%   This doesn't work for some reason 
%   Beta(:,:,i) = mvnrnd(B(:,i)', ihess(:,:,i),n);
end

M1 = mean(Beta,3);
S1 = std(Beta,[],3);


% Columns contain: Mean and Std. Dev.
% There are 2 rows for every parametr: first with mean, and second with
% standard error

T = zeros(2*8, 2);
T(1:2:end,:) = [mean(M1,1)', mean(S1,1)'];
T(2:2:end,:) = [std(M1,[],1)',std(S1,[],1)'];

%% bandwidth = 0.275 
B = Results.GWMNL0.bhat; % bandwidth = 0.45
ihess = Results.GWMNL0.ihess;
Beta = zeros(n,8,1001);

for i = 1:1001
   BX = normrnd(0,1,8,n);
   V = chol(ihess(:,:,i),'lower');
   BX = B(:,i*ones(n,1))+V*BX;
   Beta(:,:,i) = BX';
%   This doesn't work for some reason 
%   Beta(:,:,i) = mvnrnd(B(:,i)', ihess(:,:,i),n);
end

M0 = mean(Beta,3);
S0 = std(Beta,[],3);

T0 = zeros(2*8, 2);
T0(1:2:end,:) = [mean(M0,1)', mean(S0,1)'];
T0(2:2:end,:) = [std(M0,[],1)',std(S0,[],1)'];

%% bandwidth = 0.6
B = Results.GWMNL2.bhat; % bandwidth = 0.45
ihess = Results.GWMNL2.ihess;
Beta = zeros(n,8,1001);

for i = 1:1001
   BX = normrnd(0,1,8,n);
   V = chol(ihess(:,:,i),'lower');
   BX = B(:,i*ones(n,1))+V*BX;
   Beta(:,:,i) = BX';
%   This doesn't work for some reason 
%   Beta(:,:,i) = mvnrnd(B(:,i)', ihess(:,:,i),n);
end

M2 = mean(Beta,3);
S2 = std(Beta,[],3);

T2 = zeros(2*8, 2);
T2(1:2:end,:) = [mean(M2,1)', mean(S2,1)'];
T2(2:2:end,:) = [std(M2,[],1)',std(S2,[],1)'];

%%
T = [T0, T, T2];
T = T([3:14, 1:2, 15:16],:);
P = zeros(8, 6);
for i = 1:6
    P(:,i) = pv(T(1:2:end,i), T(2:2:end,i));
end
%% Output

TabOut = cell(18, 7);
TabOut(1,[2 4 6]) = {'Bandwidth = 0.275' , 'Bandwidth = 0.475' , 'Bandwidth = 0.6' };
TabOut(2,2:7) = {'Mean', 'Std. Dev.', 'Mean', 'Std. Dev.', 'Mean', 'Std. Dev.'};
T = reshape(T, [2,8,6]);
for i = 1:8
    for j = 1:6
         Tmp = P(i,j);
         Tmp2 = T(:,i,j);
         if Tmp< 0.01
             TabOut(2+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), '***']}; 
        elseif Tmp <= 0.05 && Tmp > 0.01
            TabOut(2+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), '**']}; 
        elseif Tmp <= 0.1 && Tmp > 0.05
            TabOut(2+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), '*']}; 
        elseif Tmp > 0.1
            TabOut(2+2*(i-1)+1,1+j) = {[num2str(Tmp2(1), '%8.2f'), ' ']}; 
         end
        TabOut(2+2*i,1+j) = {['''(', num2str(Tmp2(2), '%8.2f'), ')']}; 
    end
end
TabOut(3:2:17,1) ={'NAT1'; 'NAT2'; 'TRA1'; 'TRA2'; 'INF1'; 'INF2';'SQ'; 'COST' }; 

% Tabout can be then exported to excel
xlswrite('GWR_TabA1.xls', TabOut,'TableA1', 'B2');
toc;