% "Using geographically weighted choice models to account for the spatial heterogeneity of preferences"
% Wiktor Budziski, Danny Campbell, Mikoaj Czajkowski, Urka Demar and Nick Hanley

% Online codes
% 2017-09-09 version

% Table B1 Results of regressions where the dependent variables are the absolute values of differences between WTP from GWMNL and location-specific MXL. 

% This code uses Tools package from https://github.com/czaj/Tools

% Input
% File GWMNL_results.mat, which can be calculated using GWMNLcalc.m code
% File Spatial_20160223.mat, which contains GIS and socio-demographic
% variables
% File polforex_2.8.mat, which contains Latitude and Longitude coordinates

%% Estimation

tic
clear
clc
% Results from GWMNL
load('GWMNL_results.mat');
% File with GIS variables
load('Spatial_20160223.mat')
% changing order for 
tmp = [14, 20, 30, 33:36];
DVar = Spatial(:,tmp);
DVar = DVar(:, [6, 5, 7, 3, 2, 1,4]);

% Scalling of the variables
DVar(:, [1:4, 6:7]) = DVar(:, [1:4, 6:7])/100;
DVar(:,5) = DVar(:,5)/1000; % EuclAvg

% File with model coordinates 
load('polforex_2.8.mat');
Crds = [GIS1.Longitude(1:4*26:end), GIS1.Latitude(1:4*26:end)];

% Estimates from location-specific MXL
%cd('C:\Users\wbudzinski\Documents\praca\GWR\20170929\For maps')
cd('C:\Users\Admin\Documents\Praca\GWR\20171027\For maps')

load('LocalMxlScores.mat')

%B_wtp = Results.GWMNL1.bhat(1:7,:) - Scores(:,1:7)';
B_wtp = abs(Results.GWMNL1.bhat(1:7,:) - Scores(:,1:7)');
% B_wtp = log(abs(Results.GWMNL1.bhat(1:7,:) - Scores(:,1:7)')); % Dependent variable
X = [ones(1001,1), DVar]; % Explanatory variables

%% Transforming dataset from 1001 observations (multiple observations per given location) to 253 format (one observation per location)
XX = X;
B_wtpX = B_wtp;
CrdsUni = unique(Crds, 'rows'); 
NoReg = size(CrdsUni,1);
B_wtp = zeros(7,NoReg);
X = zeros(NoReg,8);
NoObs = zeros(NoReg,1);
for i = 1:NoReg
    FindIndx = find(Crds(:,1) == CrdsUni(i,1) & Crds(:,2) == CrdsUni(i,2));
    NoObs(i) = length(FindIndx);
    B_wtp(:,i) = B_wtpX(:,FindIndx(1));
    X(i,:) = XX(FindIndx(1),:);
end

X = [X, NoObs]; % Adding no. of ovservations per location

%% Estimation of the models

T = zeros(9*2,7);
P = zeros(9*2,7);
R2 = zeros(7,1);
% [b,bint, r, rint, stats]=regress(B_wtp(2,:,8)', X);
% pause;
for j = 1:7
    [b,bint, r,rint, stats]=regress(B_wtp(j,:)', X);
    R2(j) = stats(1);
    stdx = (bint(:,2) - b)/1.96;
    T(1:2:end, j) =b;
    T(2:2:end, j) =stdx;
    pval = pv(b, stdx);
    P(1:2:end, j) =pval;
end

%% Output
TabOut = cell(20,8);
TabOut(1,2:8) ={'SQ'; 'NAT1'; 'NAT2'; 'TRA1'; 'TRA2'; 'INF1'; 'INF2' }; 
T = reshape(T, [2, 9, 7]);
for i = 1:7 % SQ, NAT1... INF2
    for j = 1:9 % Different variables 
         Tmp = T(:,j,i);
         P = pv(Tmp(1), Tmp(2));
         if P< 0.01
             TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), '***']}; 
        elseif P <= 0.05 && P > 0.01
            TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), '**']}; 
        elseif P <= 0.1 && P > 0.05
            TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), '*']}; 
        elseif P > 0.1
            TabOut(1+2*(j-1)+1,1+i) = {[num2str(Tmp(1), '%8.2f'), ' ']};  
         end
        TabOut(1+2*j,1+i) = {['''(', num2str(Tmp(2), '%8.2f'), ')']}; 
    end 
    TabOut(20,1+i)  = {[num2str(R2(i), '%8.2f')]}; 

end
TabOut(2:2:18,1) ={'Cons'; 'Coniferous'; 'Decidous'; 'Mixed'; 'Age > 120'; 'Euclidean distance'; 'Built up area'; 'Species > 6'; 'No, of obs. per location' }; 
TabOut(20,1) ={'R2'};
xlswrite('GWR_TabB1.xls', TabOut,'TableB1', 'B2');

toc